@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Mixins;
-$Footprintless::Mixins::VERSION = '1.27';
+$Footprintless::Mixins::VERSION = '1.28';
 # ABSTRACT: A utility package for mixins for standard object
 # PODNAME: Footprintless::Mixins
 
@@ -16,6 +16,7 @@ use Footprintless::Command qw(
 );
 use Footprintless::Util qw(
     clean
+    dumper
     extract
     invalid_entity
     rebase
@@ -86,7 +87,13 @@ sub _download {
         && $resource->{as}
         ? ( to => File::Spec->catfile( $to, $resource->{as} ) )
         : ( to => $to );
-    return $self->{factory}->resource_manager()->download( $resource, @options );
+
+    my $path = $self->{factory}->resource_manager()->download( $resource, @options );
+    die( "$path did not exist after _download of " . dumper($resource) ) unless ( -e $path );
+    $logger->debugf( 'Successfully downloaded resource %s to %s', $resource, $path );
+    return $path;
+
+    # return $self->{factory}->resource_manager()->download($resource, @options);
 }
 
 sub _entity {
@@ -225,7 +232,7 @@ Footprintless::Mixins - A utility package for mixins for standard object
 
 =head1 VERSION
 
-version 1.27
+version 1.28
 
 =head1 DESCRIPTION
 
